/*
	This program (post_get) is developed based on MIRS0401 program get1.c.

	post_get is developed by Shinji Ushimaru.
	get1.c was developed by T.Mano (member of MIRS0401)
	Function: post_get
	MIRS acts as follows in this function.
	1. Turn to 90 degree.
	2. Go arround post with detecting IRS signal.
	3. If find IRS signal, MIRS memorize IRS code number and gets the post.
	4. MIRS retuns to the start position of 1.
*/
#include <stdio.h>
#include <errno.h>
#include <fcntl.h>
#include <unistd.h>
#include <time.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/ioctl.h>
#include <pthread.h>
#include "func_extern.h"
#include "control.h"
#include "irs_ts_ws.h"
#include "pwm_enc.h"
#include "uss.h"

//DEFINE SENSORS
#define IRS_RIGHT	3	

//DEFINE TIME&DIS&ANG
#define TURN_ANG	90
#define TURN_TIME	1750
#define DETECTING_TIME	14000
#define SLEEP_TIME	200000
#define PUSH_TIME	3000
#define IRS_SLEEP1	300000
#define IRS_SLEEP2	700000
#define PWM_SLEEP	20000
#define LOOP_SLEEP	1000

//OTHER DEFINE
#define RETRY_NUMBER	8

int post_get(int target_post){

	int rot_cur=0;
	int circle_radious2=circle_radious;
	int rot_time=0;
	int ir_code=0;

	printf("Start post_get\n\n");
	lqr_rotate(TURN_ANG,TURN_TIME);
	usleep(SLEEP_TIME);

	//exit(0);

	// Start encoder task with period of 10msec
	printf("Start encoder task.\n");
	pwm_enco_start(10);
	usleep(PWM_SLEEP);

	//Jn
	printf("Go arround target post\n");
	pwm_lqr_circle(-circle_radious2, AROUND_ANG,DETECTING_TIME);

	count.br=0;

	//񒆐ԊOcheck
	while(1){
		ir_code=irs_code_get(IRS_RIGHT);
		if(ir_code!=0){
			usleep(IRS_SLEEP1);
			// current rotation angle arround the post
			rot_cur=90/pi*(alw+arw)/circle_radious2;
			//tire stop
			pwm_both_data(0,0);
			usleep(PWM_SLEEP);
			//stop encoder task
			printf("Stop encoder task.\n");
			pwm_enco_stop();
			usleep(PWM_SLEEP);
			break;
		}

		if(count.br==1) {
			//tire stop
			pwm_both_data(0,0);
			usleep(PWM_SLEEP);
			pwm_enco_stop();
			usleep(PWM_SLEEP);
			printf("\n***********IRS was not detected.***********\n\n");
			goto BY2;
		}
	}

	printf("irs find!\n");
	printf("rot_cur=%d \n",rot_cur);

	lqr_rotate(-90,90*20);
	moveOnCircleRadius();
	lqr_rotate(-270,270*20);
	usleep(SLEEP_TIME);

	printf("move to start_circle\n");
	if(rot_cur>180){
		rot_time = (360-rot_cur)*40;
		lqr_circle(-circle_radious2,(360-rot_cur),rot_time);
	}else{
		lqr_circle(-circle_radious2,-rot_cur,rot_cur*40);
	}
BY2:
	lqr_rotate(-90,90*20);
	usleep(SLEEP_TIME);
	printf("returned to start_circle\n\n");
	printf("finished post_get().\n\n");

	return 0;
}
